@@ -21,6 +21,7 @@ BEGIN {
 			&SDL_MOUSEBUTTONUP &SDL_QUIT &SDL_SYSWMEVENT
 			&SDL_APPMOUSEFOCUS &SDL_APPINPUTFOCUS 
 			&SDL_APPACTIVE &SDL_PRESSED &SDL_RELEASED
+			&SDL_VIDEORESIZE
 			&SDLK_BACKSPACE &SDLK_TAB &SDLK_CLEAR 
 			&SDLK_RETURN &SDLK_PAUSE &SDLK_ESCAPE 
 			&SDLK_SPACE &SDLK_EXCLAIM &SDLK_QUOTEDBL 
@@ -88,6 +89,7 @@ sub SDL_APPINPUTFOCUS { return SDL::APPINPUTFOCUS(); }
 sub SDL_APPACTIVE { return SDL::APPACTIVE(); }
 sub SDL_PRESSED { return SDL::PRESSED(); }
 sub SDL_RELEASED { return SDL::RELEASED(); }
+sub SDL_VIDEORESIZE { return SDL::VIDEORESIZE(); }
 
 sub new {
 	my $proto = shift;
@@ -379,6 +381,8 @@ sub KMOD_ALT { return SDL::MOD_ALT(); }
 
 __END__;
 
+=pod
+
 =head1 NAME
 
 SDL::Event - a SDL perl extension
@@ -395,8 +399,6 @@ SDL::Event - a SDL perl extension
  
 =head1 EXPORTS
 
-C<SDL::Event> exports the following symbols by default:
- 
        SDL_IGNORE              SDL_ENABLE
        SDL_QUERY               SDL_ACTIVEEVENT
        SDL_KEYDOWN             SDL_KEYUP
@@ -405,6 +407,8 @@ C<SDL::Event> exports the following symbols by default:
        SDL_SYSWMEVENT          SDL_APPMOUSEFOCUS
        SDL_APPINPUTFOCUS       SDL_APPACTIVE
        SDL_PRESSED             SDL_RELEASED
+       SDL_VIDEORESIZE         
+
        SDLK_BACKSPACE          SDLK_TAB
        SDLK_CLEAR              SDLK_RETURN
        SDLK_PAUSE              SDLK_ESCAPE
@@ -470,10 +474,6 @@ C<SDL::Event> exports the following symbols by default:
        SDLK_LALT               SDLK_RMETA
        SDLK_LMETA
 
-For instance, C<SDLK_F12> means the key F12, C<SDLK_KP9> means the
-key labeled '9' on the keypad (KP). Check for SDL_KEYDOWN for whether a key
-was pressed or not.
-
 =head1 DESCRIPTION
 
 C<SDL::Event> offers an object-oriented approach to SDL events. By creating
@@ -516,21 +516,15 @@ available.
 
 Waits for an event end returns then. Always returns true.
 
-=head2 set()
-
-       $event->set($type,$state);
+=head2 set( type, state )
 
 Set type and state of the event.
 
-=head2 set_unicode()
-
-       $event->set_unicode($toggle);
+=head2 set_unicode( toggle )
 
 Toggle unicode on the event.
 
-=head2 set_key_repeat()
-
-       $event->set_key_repeat($delay,$interval);
+=head2 set_key_repeat( delay, interval)
 
 Sets the delay and intervall of the key repeat rate (e.g. when a user
 holds down a key on the keyboard).
@@ -555,26 +549,18 @@ holds down a key on the keyboard).
 
 =head2 motion_x()
 
-       my $dist = $event->motion_x();
-
 Returns the motion of the mouse in X direction as an absolute value.
 
 =head2 motion_y()
 
-       my $dist = $event->motion_y();
-
 Returns the motion of the mouse in Y direction as an absolute value.
 
 =head2 motion_xrel()
 
-       my $rel_dist = $event->motion_xrel();
-
 Returns the motion of the mouse in X direction as a relative value.
 
 =head2 motion_yrel()
 
-       my $rel_dist = $event->motion_xrel();
-
 Returns the motion of the mouse in Y direction as a relative value.
 
 =head2 button_state()
@@ -589,12 +575,12 @@ Returns the state of the mouse buttons.
 
 =head1 AUTHOR
 
- David J. Goehrig
- Documentation by Tels <http://bloodgate.com/>
+David J. Goehrig
+Documentation by Tels <http://bloodgate.com/>
 
 =head1 SEE ALSO
 
-  perl(1) and L<SDL::App>.
+L<perl> L<SDL::App>
 
 =cut
 
