@@ -57,3 +57,29 @@ sub color {
 	}
 }
 
+1;
+
+__END__;
+
+=pod
+
+=head1 NAME
+
+SDL::OpenGL::Cube
+
+=head1 DESCRIPTION
+
+This module demonstrates how to create a simple cube model in OpenGL
+It can be used for creating more elaborate models.  This is not intended
+to be production level code, but rather a starting point for future
+development of useful base models.
+
+=head1 AUTHOR
+
+David J. Goehrig
+
+=head1 SEE ALSO
+
+L<perl> L<SDL::OpenGL>
+
+=cut
