@@ -4,11 +4,11 @@ use strict;
 use warnings;
 
 use SDL;
+use SDL::Surface;
 use SDL::App;
-use SDL::GraphicTool;
+use SDL::Tool::Graphic;
 
-
-my $app = new SDL::App(-title	=> "GraphicTool Test",
+my $app = new SDL::App(-title	=> "Graphic Tool Test",
 		       -width	=> 640,
 		       -height	=> 480,
 		       -depth	=> 16,
@@ -23,7 +23,7 @@ $sprite->set_color_key(SDL_SRCCOLORKEY, 0, 0);
 $sprite->display_format();
 
 #Test Zoom
-my $graphicTool = new SDL::GraphicTool();
+my $graphicTool = new SDL::Tool::Graphic();
 $graphicTool->zoom($sprite, .5, .5, 1);
 
 my $sprite_rect = new SDL::Rect(	-x=>0,
